@@ -1,12 +1,84 @@
 package Data::TUID;
 BEGIN {
-  $Data::TUID::VERSION = '0.0121';
+  $Data::TUID::VERSION = '0.0122';
 }
 # ABSTRACT: A smaller and more communicable pseudo-UUID
 
 use warnings;
 use strict;
 
+
+use vars qw/@ISA @EXPORT/; @ISA = qw/Exporter/; @EXPORT = qw/tuid/;
+
+use Encode::Base32::Crockford qw/base32_encode/;
+
+use Data::TUID::BestUUID;
+
+sub new_uuid {
+    return Data::TUID::BestUUID->new_uuid( @_ );
+}
+
+sub uuid_to_canonical {
+    return Data::TUID::BestUUID->uuid_to_canonical( @_ );
+}
+
+sub tuid {
+    shift if @_ && $_[0] eq __PACKAGE__;
+    my %given;
+    if ( @_ == 1 ) {
+        %given = ( length => shift );
+    }
+    else {
+        %given = @_;
+    }
+
+    my $uuid = $given{uuid} || new_uuid;
+    $uuid = uuid_to_canonical( $uuid );
+
+    my @tuid;
+    {
+        my $uuid = $uuid;
+        $uuid =~ s/-//g;
+        my @hex = unpack( 'A8 A8 A8 A8', $uuid );
+        my @value = map { hex $_ } @hex;
+        my @base32 = map { base32_encode $_ } @value;
+        @tuid = @base32;
+    }
+
+    my $all;
+    my $size = $given{size};
+    my $length = $given{length};
+    if ( $length && ( $length == -1 || $length >= 28 ) || $size && $size == -1 ) {
+        return join '', @tuid;
+    }
+    $length = 8 unless $length || $size;
+    if ( ! $all && $length ) {
+        $size = int( $length / 4 );
+        $size += $length % 4;
+    }
+    $size = $size < 1 ? 1 : $size > 7 ? 7 : $size;
+
+    @tuid = map { substr $_, -$size, $size } @tuid;
+    my $tuid = join '', @tuid;
+    $tuid = substr $tuid, 0, $length if $length;
+
+    return $tuid;
+}
+
+
+1;
+
+__END__
+=pod
+
+=head1 NAME
+
+Data::TUID - A smaller and more communicable pseudo-UUID
+
+=head1 VERSION
+
+version 0.0122
+
 =head1 SYNOPSIS
 
     use Data::TUID
@@ -72,7 +144,7 @@ The arguments are:
 
     length  The length of the TUID returned. By default 8. A length of -1 will result in the whole
             UUID being used, and a variable length TUID being returned (somewhere between 25 to 28)
-            
+
 =head1 SEE ALSO
 
 L<Encode::Base32::Crockford>
@@ -81,67 +153,18 @@ L<Data::UUID::LibUUID>
 
 L<http://www.crockford.com/wrmg/base32.html>
 
-=cut
-
-use vars qw/@ISA @EXPORT/; @ISA = qw/Exporter/; @EXPORT = qw/tuid/;
-
-use Encode::Base32::Crockford qw/base32_encode/;
-
-use Data::TUID::BestUUID;
-
-sub new_uuid {
-    return Data::TUID::BestUUID->new_uuid( @_ );
-}
-
-sub uuid_to_canonical {
-    return Data::TUID::BestUUID->uuid_to_canonical( @_ );
-}
-
-sub tuid {
-    shift if @_ && $_[0] eq __PACKAGE__;
-    my %given;
-    if ( @_ == 1 ) {
-        %given = ( length => shift );
-    }
-    else {
-        %given = @_;
-    }
-
-    my $uuid = $given{uuid} || new_uuid;
-    $uuid = uuid_to_canonical( $uuid );
-
-    my @tuid;
-    {
-        my $uuid = $uuid;
-        $uuid =~ s/-//g;
-        my @hex = unpack( 'A8 A8 A8 A8', $uuid );
-        my @value = map { hex $_ } @hex;
-        my @base32 = map { base32_encode $_ } @value;
-        @tuid = @base32;
-    }
-
-    my $all;
-    my $size = $given{size};
-    my $length = $given{length};
-    if ( $length && ( $length == -1 || $length >= 28 ) || $size && $size == -1 ) {
-        return join '', @tuid;
-    }
-    $length = 8 unless $length || $size;
-    if ( ! $all && $length ) {
-        $size = int( $length / 4 );
-        $size += $length % 4;
-    }
-    $size = $size < 1 ? 1 : $size > 7 ? 7 : $size;
-
-    @tuid = map { substr $_, -$size, $size } @tuid;
-    my $tuid = join '', @tuid;
-    $tuid = substr $tuid, 0, $length if $length;
-
-    return $tuid;
-}
-
 =head1 ACKNOWLEDGEMENTS
 
+=head1 AUTHOR
+
+Robert Krimen <robertkrimen@gmail.com>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2010 by Robert Krimen.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
 
-1;
