@@ -68,3 +68,28 @@ sub uuid_to_canonical {
 }
 
 1;
+
+__END__
+=pod
+
+=head1 NAME
+
+Data::TUID::BestUUID
+
+=head1 VERSION
+
+version 0.0122
+
+=head1 AUTHOR
+
+Robert Krimen <robertkrimen@gmail.com>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2010 by Robert Krimen.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
+
